"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = require("react");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _logging = require("@edx/frontend-platform/logging");
var _i18n = require("@edx/frontend-platform/i18n");
var _paragon = require("@edx/paragon");
var _BaseModal = _interopRequireDefault(require("../BaseModal"));
var _BlocksList = _interopRequireDefault(require("./BlocksList"));
var _BlockLink = _interopRequireDefault(require("./BlockLink"));
var _SearchBlocks = _interopRequireDefault(require("./SearchBlocks"));
var _utils = require("./utils");
var _api = require("./api");
var _messages = _interopRequireDefault(require("./messages"));
require("./index.scss");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const InsertLinkModal = _ref => {
  let {
    courseId,
    isOpen,
    onClose,
    editorRef
  } = _ref;
  const intl = (0, _i18n.useIntl)();
  const [searchField, setSearchField] = (0, _react.useState)('');
  const [blocksSearched, setBlocksSearched] = (0, _react.useState)(false);
  const [blockSelected, setBlocksSelected] = (0, _react.useState)(null);
  const [blocksList, setBlocksList] = (0, _react.useState)(null);
  const [invalidUrlInput, setInvalidUrlInput] = (0, _react.useState)(false);
  const [inputUrlValue, setInputUrlValue] = (0, _react.useState)('');
  const handleSearchedBlocks = isSearched => {
    setBlocksSearched(isSearched);
  };
  const handleSelectedBlock = blockSelectedFromList => {
    setBlocksSelected(blockSelectedFromList);
    setInputUrlValue('');
  };
  const handleCloseLink = () => {
    setSearchField('');
    setBlocksSelected(null);
  };
  const handleChangeInputUrl = _ref2 => {
    let {
      target: {
        value
      }
    } = _ref2;
    setInputUrlValue(value);
  };
  const handleSave = () => {
    const editor = editorRef.current;
    const urlPath = blockSelected?.lmsWebUrl || inputUrlValue;
    if (editor && urlPath) {
      const validateUrl = (0, _utils.isValidURL)(urlPath);
      if (!validateUrl) {
        setInvalidUrlInput(true);
        return;
      }
      const selectedText = editor.selection.getContent({
        format: 'text'
      });
      if (selectedText.trim() !== '') {
        const linkHtml = `<a href="${urlPath}" data-mce-href="${urlPath}" target="_blank">${selectedText}</a>`;
        editor.selection.setContent(linkHtml);
      }
    }
    onClose();
  };
  (0, _react.useEffect)(() => {
    const getBlocksList = async () => {
      try {
        const blocksData = await (0, _api.getBlocksFromCourse)(courseId);
        const {
          blocks: blocksResponse,
          root: rootBlocksResponse
        } = blocksData;
        const blockListFormatted = (0, _utils.formatBlocks)(blocksResponse, rootBlocksResponse);
        setBlocksList(blockListFormatted);
      } catch (error) {
        (0, _logging.logError)(error);
      }
    };
    getBlocksList();
  }, []);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_BaseModal.default, {
    isOpen: isOpen,
    close: onClose,
    title: intl.formatMessage(_messages.default.insertLinkModalTitle),
    confirmAction: /*#__PURE__*/(0, _jsxRuntime.jsx)(_paragon.Button, {
      variant: "primary",
      onClick: handleSave,
      children: intl.formatMessage(_messages.default.insertLinkModalButtonSave)
    }),
    children: blockSelected ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_BlockLink.default, {
      path: blockSelected.path,
      onCloseLink: handleCloseLink
    }) : /*#__PURE__*/(0, _jsxRuntime.jsxs)(_paragon.Tabs, {
      variant: "tabs",
      defaultActiveKey: "course-pages",
      id: "uncontrolled-tab-example",
      className: "mt-3 justify-content-around w-100",
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_paragon.Tab, {
        eventKey: "course-pages",
        title: intl.formatMessage(_messages.default.insertLinkModalCoursePagesTabTitle),
        className: "col-12 w-100 tabs-container",
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_SearchBlocks.default, {
          blocks: blocksList || {},
          onSearchFilter: handleSearchedBlocks,
          searchInputValue: searchField,
          onBlockSelected: handleSelectedBlock
        }), !blocksSearched && /*#__PURE__*/(0, _jsxRuntime.jsx)(_BlocksList.default, {
          blocks: blocksList || {},
          onBlockSelected: handleSelectedBlock
        })]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_paragon.Tab, {
        eventKey: "url",
        title: intl.formatMessage(_messages.default.insertLinkModalUrlTabTitle),
        className: "col-12 tabs-container",
        children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_paragon.Form.Group, {
          isInvalid: invalidUrlInput,
          className: "my-4",
          children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_paragon.Form.Control, {
            placeholder: intl.formatMessage(_messages.default.insertLinkModalInputPlaceholder),
            onChange: handleChangeInputUrl
          }), invalidUrlInput && /*#__PURE__*/(0, _jsxRuntime.jsx)(_paragon.Form.Control.Feedback, {
            type: "invalid",
            children: intl.formatMessage(_messages.default.insertLinkModalInputErrorMessage)
          })]
        })
      })]
    })
  });
};
InsertLinkModal.propTypes = {
  courseId: _propTypes.default.string.isRequired,
  isOpen: _propTypes.default.bool.isRequired,
  onClose: _propTypes.default.func.isRequired,
  editorRef: _propTypes.default.shape({
    current: _propTypes.default.shape({
      selection: _propTypes.default.shape({
        getContent: _propTypes.default.func,
        setContent: _propTypes.default.func
      })
    })
  }).isRequired
};
var _default = exports.default = InsertLinkModal;
//# sourceMappingURL=index.js.map